@@ -1,13 +1,10 @@
 #this code block is needed for backwards compatibility with older Spark versions
 from pyspark import SparkContext
 from packaging import version
-# sc = SparkContext.getOrCreate()
-# if version.parse(sc.version) < version.parse("3.2.0"):
-#   import databricks.koalas as pd
-#   needs_koalas = True
-# else:
-import pyspark.pandas as pd
-
+try:
+  import pyspark.pandas as pd
+except:
+  import databricks.koalas as pd 
 
 from labelspark.flatten_bronze_table import flatten_bronze_table
 from labelspark.add_json_answers_to_dictionary import add_json_answers_to_dictionary
@@ -24,10 +21,7 @@ def bronze_to_silver(bronze_table):
     if video:
         bronze_table = bronze_table.withColumnRenamed("Label.frameNumber",
                                                       "frameNumber")
-    if needs_koalas:
-        bronze_table = bronze_table.to_koalas()
-    else:
-        bronze_table = bronze_table.to_pandas_on_spark()
+    bronze_table = bronze_table.to_pandas_on_spark()
 
     new_json = []
     for index, row in bronze_table.iterrows():
