@@ -167,7 +167,6 @@ class Client:
         for data_row in data_row_metadata:
             global_key = str(data_row_id_to_global_key[str(data_row.data_row_id)])
             root_global_key = global_key[:-3] if global_key[-3:-1] == "__" else global_key            
-            print(global_key, root_global_key)
             for field in data_row.fields:
                 if field.schema_id in metadata_schema_to_name_key:
                     metadata_col = metadata_schema_to_name_key[field.schema_id]
@@ -224,7 +223,7 @@ class Client:
                     table_value = spark_table.filter(f"{global_key_col} = '{global_key}'").collect()[0].__getitem__(field_name)
                     table_name_key = f"{field_name}///{table_value}"
                     field.value = metadata_name_key_to_schema[table_name_key] if table_name_key in metadata_name_key_to_schema.keys() else table_value
-            upload_metadata.append(DataRowMetadata(data_row_id=data_row.data_row_id, fields=new_metadata)
+            upload_metadata.append(DataRowMetadata(data_row_id=data_row.data_row_id, fields=new_metadata))
         results = lb_mdo.bulk_upsert(upload_metadata)
         endtime = datetime.now()
         print(f'Upsert Labelbox metadata complete\n Start Time: {starttime}\n End Time: {endtime}\n Total Time: {endtime-starttime}\nData rows upserted: {len(upload_metadata)}')         
