@@ -244,12 +244,9 @@ def column_upsert_udf():
     """      
     return udf(upsert_function, StringType())
 
-def generate_random_keys(spark_table, column_name="new_global_key"):
+def random_keys_udf():
     """ Adds a new column to your spark_table with randomly generated unique keys
     """
     def randomizer():
-        return str(uuid.uuid4())
-    randomizer_udf = udf(randomizer, StringType())
-    spark_table.withColumn(column_name, randomizer_udf())
-    
-    
+        return f"{str(uuid.uuid4())}-{str(uuid.uuid4())}"
+    return udf(randomizer, StringType())
